@@ -1,3 +1,4 @@
+import argparse
 import sys
 from typing import Text
 
@@ -8,7 +9,7 @@ def install_token(token: Text) -> None:
     config_location = Path().home() / ".ipython/nbextensions/jupyter-cogram"
     token_file_name = "cogram_auth_token"
 
-    loc = (config_location / token_file_name).absolute()
+    loc = config_location.absolute()
 
     if not loc.is_dir():
         loc.mkdir(parents=True)
@@ -21,12 +22,25 @@ def install_token(token: Text) -> None:
 
 
 if __name__ == "__main__":
-    # noinspection PyBroadException
-    try:
-        token = sys.argv[1]
-        install_token(token)
-    except Exception as e:
+    parser = argparse.ArgumentParser(description="Set your Cogram API token")
+    parser.add_argument(
+        "-t",
+        "--token",
+        help="Your Cogram API token",
+        required=True,
+    )
+
+    token = parser.parse_args().token
+
+    if not token:
         print(
             "⚠️  Could not find token! The full command is\n"
-            "python3 -m jupyter_cogram YOUR_TOKEN"
+            "python3 -m jupyter_cogram --token YOUR_TOKEN"
         )
+        sys.exit(1)
+
+    # noinspection PyBroadException
+    try:
+        install_token(token)
+    except Exception as e:
+        print("⚠️  Could not install token:\n{e}")
